Learn R Programming

DemografixeR (version 0.1.1)

get_api_key: Get previously saved API keys

Description

Function to get the previously saved API key. It has the advantage that it is not necessary to explicitly publish the key in the users code. Just do it one time and you're set. To save an API, use the save_api_key function. To remove a previously saved key, use the remove_api_key function.

Usage

get_api_key()

Arguments

Value

Returns the saved API key in the environment. If no API key has been saved, returns NULL value.

Warning

Please be careful when dealing with API keys and other secrets & tokens - keep them private and do not publish them.

See Also

save_api_key, remove_api_key

Examples

Run this code
# NOT RUN {
get_api_key(type="genderize")
get_api_key(type="agify")
get_api_key(type="nationalize")
# }

Run the code above in your browser using DataLab