Returns the estimated nationality from a given name.
nationalize(
name,
simplify = TRUE,
sliced = TRUE,
apikey = get_api_key(),
meta = FALSE
)Name/s to estimate the nationality. Can be a single
character string or a character vector. Obligatory parameter.
Defines if the result should be returned as a single vector
or a data.frame with additional information. By default set to
TRUE, which returns a vector.
Names can have multiple estimated nationalities ranked by
probability. This logical parameter allows to "slice"/keep only the
parameter with the highest probability to keep a single estimate for each
name. By default set to TRUE.
Optional parameter to pass the API key. The API is free for up
to 1000 names/day. No sign up or API key needed. Yet, if more requests
would be needed, visit the
nationalize.io store and the obtained
API key can be passed through this parameter. The API can also be saved one
time through the save_api_key function, so it is not necessary to
call again.
Logical parameter to define if API related information
should be returned. By default set to FALSE. Returns information
about:
The amount of names available in the current time window
The number of names left in the current time window
Seconds remaining until a new time window opens
Returns the estimated nationality as the common
ISO 3166-1 alpha-2
country code. The result can be in a single character vector form or
a data.frame with additional information.
Please be aware about local privacy protection regulations such as GDPR when dealing with personal data.
The function automatically handles pagination (max. 10 names per API
request), missing values & duplicated values. If a name is duplicated for
the same country_id (if the parameter has been passed), it will
handle the request as a a single name to save requests, returning the same
value for the duplicated names. To see more details about the API
documentation, visit the nationalize.io
website.
# NOT RUN {
nationalize(name=c("Ben", "Maria"))
# }
Run the code above in your browser using DataLab